GradientRangeSliderTrackShape class

Inheritance

Constructors

GradientRangeSliderTrackShape({required List<Color> gradientColors})
const

Properties

gradientColors List<Color>
final
hashCode int
The hash code for this object.
no setterinherited
isRounded bool
Whether the track shape is rounded. This is used to determine the correct position of the thumbs in relation to the track. Defaults to false.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPreferredRect({required RenderBox parentBox, Offset offset = Offset.zero, required SliderThemeData sliderTheme, bool isEnabled = false, bool isDiscrete = false}) Rect
Returns the preferred bounds of the shape.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset, {required RenderBox parentBox, required SliderThemeData sliderTheme, required Animation<double> enableAnimation, required Offset startThumbCenter, required Offset endThumbCenter, required TextDirection textDirection, bool isEnabled = false, bool isDiscrete = false}) → void
Paints the track shape based on the state passed to it.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited